@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,9 +16,11 @@
 """Common flags for iam commands."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.util.args import common_args
 
 
 def GetRoleFlag(verb):
@@ -48,6 +50,17 @@ def GetOrgFlag(verb):
       help='The organization of the role you want to {0}.'.format(verb))
 
 
+def GetProjectFlag(verb):
+  help_text = 'The project of the role you want to {0}.'.format(verb)
+  return common_args.ProjectArgument(help_text_to_prepend=help_text)
+
+
+def AddParentFlags(parser, verb, required=True):
+  parent_group = parser.add_mutually_exclusive_group(required=required)
+  GetOrgFlag(verb).AddToParser(parent_group)
+  GetProjectFlag(verb).AddToParser(parent_group)
+
+
 _RESOURCE_NAME_HELP = """\
 The full resource name or URI to {verb}.
 
