@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,14 +28,14 @@ A typical use would be:
 """
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
-import fnmatch
 import os
-import re
 
 import enum
 
+from googlecloudsdk.command_lib.util import glob
 from googlecloudsdk.core import exceptions
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
@@ -67,11 +67,7 @@ _ENDS_IN_ODD_NUMBER_SLASHES_RE = r'(?<!\\)\\(\\\\)*$'
 
 
 class InternalParserError(Exception):
-  """An internal error in gcloudignore parsing."""
-
-
-class InvalidLineError(InternalParserError):
-  """Error indicating that a line of the ignore file was invalid."""
+  """An internal error in ignore file parsing."""
 
 
 class BadFileError(InternalParserError):
@@ -82,8 +78,12 @@ class BadIncludedFileError(exceptions.Error):
   """Error indicating that a provided file was invalid."""
 
 
+class SymlinkLoopError(exceptions.Error):
+  """Error indicating that there is a symlink loop."""
+
+
 class Match(enum.Enum):
-  """Indicates whether a ignore pattern matches or explicitly includes a path.
+  """Indicates whether an ignore pattern matches or explicitly includes a path.
 
   INCLUDE: path matches, and is included
   IGNORE: path matches, and is ignored
@@ -95,91 +95,6 @@ class Match(enum.Enum):
   NO_MATCH = 3
 
 
-def _HandleSpaces(line):
-  """Handles spaces in a line.
-
-  In particular, deals with trailing spaces (which are stripped unless
-  escaped) and escaped spaces throughout the line (which are unescaped).
-
-  Args:
-    line: str, the line
-
-  Returns:
-    str, the line with spaces handled
-  """
-  def _Rstrip(line):
-    """Strips unescaped trailing spaces."""
-    # First, make the string into "tokens": a backslash followed by any
-    # character is one token; any other character is a token on its own.
-    tokens = []
-    i = 0
-    while i < len(line):
-      curr = line[i]
-      if curr == '\\':
-        if i + 1 >= len(line):
-          tokens.append(curr)
-          break  # Pass through trailing backslash
-        tokens.append(curr + line[i+1])
-        i += 2
-      else:
-        tokens.append(curr)
-        i += 1
-
-    # Then, strip the trailing space tokens.
-    res = []
-    only_seen_spaces = True
-    for curr in reversed(tokens):
-      if only_seen_spaces and curr == ' ':
-        continue
-      only_seen_spaces = False
-      res.append(curr)
-
-    return ''.join(reversed(res))
-
-  def _UnescapeSpaces(line):
-    """Unescapes all spaces in a line."""
-    return line.replace('\\ ', ' ')
-
-  return _UnescapeSpaces(_Rstrip(line))
-
-
-def _Unescape(line):
-  r"""Unescapes a line.
-
-  The escape character is '\'. An escaped backslash turns into one backslash;
-  any other escaped character is ignored.
-
-  Args:
-    line: str, the line to unescape
-
-  Returns:
-    str, the unescaped line
-
-  """
-  return re.sub(r'\\([^\\])', r'\1', line).replace('\\\\', '\\')
-
-
-def _GetPathPrefixes(path):
-  """Returns all prefixes for the given path, inclusive.
-
-  That is, for 'foo/bar/baz', returns ['', 'foo', 'foo/bar' 'foo/bar/baz'].
-
-  Args:
-    path: str, the path for which to get prefixes.
-
-  Returns:
-    list of str, the prefixes.
-  """
-  path_prefixes = [path]
-  path_reminder = True
-  # Apparently which one is empty when operating on top-level directory depends
-  # on your configuration.
-  while path and path_reminder:
-    path, path_reminder = os.path.split(path)
-    path_prefixes.insert(0, path)
-  return path_prefixes
-
-
 class Pattern(object):
   """An ignore-file pattern.
 
@@ -196,70 +111,9 @@ class Pattern(object):
     self.negated = negated
     self.must_be_dir = must_be_dir
 
-  def _MatchesHelper(self, pattern_parts, path):
-    """Determines whether the given pattern matches the given path.
-
-    Args:
-      pattern_parts: list of str, the list of pattern parts that must all match
-        the path.
-      path: str, the path to match.
-
-    Returns:
-      bool, whether the patch matches the pattern_parts (Matches() will convert
-        this into a Match value).
-    """
-    # This method works right-to-left. It checks that the right-most pattern
-    # part matches the right-most path part, and that the remaining pattern
-    # matches the remaining path.
-    if not pattern_parts:
-      # We've reached the end of the pattern! Success.
-      return True
-    if path is None:
-      # Distinguish between '*' and '/*'. The former should match '' (the root
-      # directory) but the latter should not.
-      return False
-
-    pattern_part = pattern_parts[-1]
-    remaining_pattern = pattern_parts[:-1]
-    if path:  # normpath turns '' into '.', which confuses fnmatch later
-      path = os.path.normpath(path)
-    remaining_path, path_part = os.path.split(path)
-    if not path_part:
-      # See note above.
-      remaining_path = None
-
-    if pattern_part == '**':
-      # If the path would match the remaining pattern_parts after skipping 0-all
-      # of the trailing path parts, the whole pattern matches.
-      #
-      # That is, if we have `<pattern>/**` as a pattern and `foo/bar` as our
-      # path, if any of ``, `foo`, and `foo/bar` match `<pattern>`, we return
-      # true.
-      path_prefixes = _GetPathPrefixes(path)
-      # '**' patterns only match against the full path (essentially, they have
-      # an implicit '/' at the front of the pattern). An empty string at the
-      # beginning of remaining_pattern simulates this.
-      #
-      # pylint: disable=g-explicit-bool-comparison
-      # In this case, it's much clearer to show what we're checking for.
-      if not (remaining_pattern and remaining_pattern[0] == ''):
-        remaining_pattern.insert(0, '')
-      # pylint: enable=g-explicit-bool-comparison
-      return any(self._MatchesHelper(remaining_pattern, prefix) for prefix
-                 in path_prefixes)
-
-    if not fnmatch.fnmatch(path_part, pattern_part):
-      # If the current pattern part doesn't match the current path part, the
-      # whole pattern can't match the whole path. Give up!
-      return False
-
-    return self._MatchesHelper(remaining_pattern, remaining_path)
-
   def Matches(self, path, is_dir=False):
     """Returns a Match for this pattern and the given path."""
-    if self.must_be_dir and not is_dir:
-      return Match.NO_MATCH
-    if self._MatchesHelper(self.pattern.split('/'), path):
+    if self.pattern.Matches(path, is_dir=is_dir):
       return Match.INCLUDE if self.negated else Match.IGNORE
     else:
       return Match.NO_MATCH
@@ -281,25 +135,13 @@ class Pattern(object):
         invalid consecutive stars).
     """
     if line.startswith('#'):
-      raise InvalidLineError('Line [{}] begins with `#`.'.format(line))
+      raise glob.InvalidLineError('Line [{}] begins with `#`.'.format(line))
     if line.startswith('!'):
       line = line[1:]
       negated = True
     else:
       negated = False
-    if line.endswith('/'):
-      line = line[:-1]
-      must_be_dir = True
-    else:
-      must_be_dir = False
-    line = _HandleSpaces(line)
-    if re.search(_ENDS_IN_ODD_NUMBER_SLASHES_RE, line):
-      raise InvalidLineError(
-          'Line [{}] ends in an odd number of [\\]s.'.format(line))
-    line = _Unescape(line)
-    if not line:
-      raise InvalidLineError('Line [{}] is blank.'.format(line))
-    return cls(line, negated=negated, must_be_dir=must_be_dir)
+    return cls(glob.Glob.FromString(line), negated=negated)
 
 
 class FileChooser(object):
@@ -322,7 +164,7 @@ class FileChooser(object):
     """Returns whether the given file/directory should be included.
 
     This is determined according to the rules at
-    https://git-scm.com/docs/gitignore.
+    https://git-scm.com/docs/gitignore except that symlinks are followed.
 
     In particular:
     - the method goes through pattern-by-pattern in-order
@@ -332,12 +174,12 @@ class FileChooser(object):
 
     Args:
       path: str, the path (relative to the root upload directory) to test.
-      is_dir: bool, whether the path is a directory (not a file or symlink).
+      is_dir: bool, whether the path is a directory (or symlink to a directory).
 
     Returns:
       bool, whether the file should be uploaded
     """
-    path_prefixes = _GetPathPrefixes(path)[1:]  # root dir can't be matched
+    path_prefixes = glob.GetPathPrefixes(path)[1:]  # root dir can't be matched
     for path_prefix in path_prefixes:
       prefix_match = Match.NO_MATCH
       for pattern in self.patterns:
@@ -350,6 +192,29 @@ class FileChooser(object):
         return False
     return True
 
+  def _RaiseOnSymlinkLoop(self, full_path):
+    """Raise SymlinkLoopError if the given path is a symlink loop."""
+    if not os.path.islink(full_path):
+      return
+
+    # Does it refer to itself somehow?
+    p = os.readlink(full_path)
+    targets = set()
+    while os.path.islink(p):
+      if p in targets:
+        raise SymlinkLoopError(
+            'The symlink [{}] refers to itself.'.format(full_path))
+      targets.add(p)
+      p = os.readlink(p)
+    # Does it refer to its containing directory?
+    p = os.path.dirname(full_path)
+    while p and os.path.basename(p):
+      if os.path.samefile(p, full_path):
+        raise SymlinkLoopError(
+            'The symlink [{}] refers to its own containing directory.'.format(
+                full_path))
+      p = os.path.dirname(p)
+
   def GetIncludedFiles(self, upload_directory, include_dirs=True):
     """Yields the files in the given directory that this FileChooser includes.
 
@@ -359,21 +224,26 @@ class FileChooser(object):
 
     Yields:
       str, the files and directories that should be uploaded.
+    Raises:
+      SymlinkLoopError: if there is a symlink referring to its own containing
+      dir or itself.
     """
-    for dirpath, dirnames, filenames in os.walk(upload_directory):
+    for dirpath, dirnames, filenames in os.walk(
+        six.text_type(upload_directory), followlinks=True):
       if dirpath == upload_directory:
         relpath = ''
       else:
         relpath = os.path.relpath(dirpath, upload_directory)
       for filename in filenames:
         file_relpath = os.path.join(relpath, filename)
+        self._RaiseOnSymlinkLoop(os.path.join(dirpath, filename))
         if self.IsIncluded(file_relpath):
           yield file_relpath
       for dirname in dirnames[:]:  # make a copy since we modify the original
         file_relpath = os.path.join(relpath, dirname)
-        # Don't treat symlinks as directories, even though os.walk does.
-        is_dir = not os.path.islink(os.path.join(dirpath, dirname))
-        if self.IsIncluded(file_relpath, is_dir=is_dir):
+        full_path = os.path.join(dirpath, dirname)
+        if self.IsIncluded(file_relpath, is_dir=True):
+          self._RaiseOnSymlinkLoop(full_path)
           if include_dirs:
             yield file_relpath
         else:
@@ -407,11 +277,10 @@ class FileChooser(object):
         if line[1:].lstrip().startswith(cls._INCLUDE_DIRECTIVE):
           patterns.extend(cls._GetIncludedPatterns(line, dirname, recurse))
         continue  # lines beginning with '#' are comments
-      line_with_spaces_gone = _HandleSpaces(line)
-      if (not line_with_spaces_gone or
-          re.search(_ENDS_IN_ODD_NUMBER_SLASHES_RE, line_with_spaces_gone)):
-        continue  # blank line or trailing / both get ignored
-      patterns.append(Pattern.FromString(line))
+      try:
+        patterns.append(Pattern.FromString(line))
+      except glob.InvalidLineError:
+        pass  # Ignore invalid lines
     return cls(patterns)
 
   @classmethod
@@ -500,11 +369,14 @@ def _GetIgnoreFileContents(default_ignore_file,
 
 def GetFileChooserForDir(
     directory, default_ignore_file=DEFAULT_IGNORE_FILE, write_on_disk=True,
-    gcloud_ignore_creation_predicate=_GitFilesExist, include_gitignore=True):
+    gcloud_ignore_creation_predicate=_GitFilesExist, include_gitignore=True,
+    ignore_file=None):
   """Gets the FileChooser object for the given directory.
 
   In order of preference:
-  - Uses .gcloudignore file in the top-level directory.
+  - If ignore_file is not none, use it to skip files.
+    If the specified file does not exist, raise error.
+  - Use .gcloudignore file in the top-level directory.
   - Evaluates creation predicate to determine whether to generate .gcloudignore.
     include_gitignore determines whether the generated .gcloudignore will
     include the user's .gitignore if one exists. If the directory is not
@@ -525,6 +397,8 @@ def GetFileChooserForDir(
       .gitignore file or .git directory.
     include_gitignore: bool, whether the generated gcloudignore should include
       the user's .gitignore if present.
+    ignore_file: custom ignore_file name.
+              Override .gcloudignore file to customize files to be skipped.
 
   Raises:
     BadIncludedFileError: if a file being included does not exist or is not in
@@ -534,20 +408,24 @@ def GetFileChooserForDir(
     FileChooser: the FileChooser for the directory. If there is no .gcloudignore
     file and it can't be created the returned FileChooser will choose all files.
   """
-  if not properties.VALUES.gcloudignore.enabled.GetBool():
-    log.info('Not using a .gcloudignore file since gcloudignore is globally '
-             'disabled.')
-    return FileChooser([])
-  gcloudignore_path = os.path.join(directory, IGNORE_FILE_NAME)
+
+  if ignore_file:
+    gcloudignore_path = os.path.join(directory, ignore_file)
+  else:
+    if not properties.VALUES.gcloudignore.enabled.GetBool():
+      log.info('Not using a .gcloudignore file since gcloudignore is globally '
+               'disabled.')
+      return FileChooser([])
+    gcloudignore_path = os.path.join(directory, IGNORE_FILE_NAME)
   try:
     chooser = FileChooser.FromFile(gcloudignore_path)
   except BadFileError:
     pass
   else:
-    log.info('Using .gcloudignore file at [{}].'.format(gcloudignore_path))
+    log.info('Using ignore file at [{}].'.format(gcloudignore_path))
     return chooser
   if not gcloud_ignore_creation_predicate(directory):
-    log.info('Not using a .gcloudignore file.')
+    log.info('Not using ignore file.')
     return FileChooser([])
 
   ignore_contents = _GetIgnoreFileContents(default_ignore_file, directory,
