@@ -411,7 +411,7 @@ def _RunCreate(compute_api,
       custom_cpu=args.custom_cpu,
       custom_memory=args.custom_memory,
       ext=getattr(args, 'custom_extensions', None),
-      vm_gen=getattr(args, 'custom_vm_gen', None))
+      vm_type=getattr(args, 'custom_vm_type', None))
 
   guest_accelerators = (
       instance_template_utils.CreateAcceleratorConfigMessages(
