@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,9 @@
 """Command for moving instances."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute.operations import poller
 from googlecloudsdk.api_lib.util import waiter
@@ -106,4 +108,9 @@ Move.detailed_help = {
 
         will move the instance called example-instance-1 with its all attached
         persistent disks, currently running in us-central1-b, to us-central1-f.
+
+        Please note that gcloud compute instances move does not yet support
+        instances which have regional persistent disks attached. Please see
+        https://cloud.google.com/compute/docs/disks/regional-persistent-disk for
+        more details.
     """}
