@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,10 +12,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Delete cluster command."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import exceptions as apitools_exceptions
 
 from googlecloudsdk.api_lib.container import kubeconfig as kconfig
@@ -26,6 +28,7 @@ from googlecloudsdk.command_lib.container import flags
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 from googlecloudsdk.core.console import console_io
+import six
 
 
 class Delete(base.DeleteCommand):
@@ -52,7 +55,7 @@ class Delete(base.DeleteCommand):
 
     Args:
       parser: An argparse.ArgumentParser-like object. It is mocked out in order
-          to capture some information, but behaves like an ArgumentParser.
+        to capture some information, but behaves like an ArgumentParser.
     """
     parser.add_argument(
         'names',
@@ -84,11 +87,11 @@ class Delete(base.DeleteCommand):
     for name in args.names:
       cluster_refs.append(adapter.ParseCluster(name, location))
     console_io.PromptContinue(
-        message=util.ConstructList(
-            'The following clusters will be deleted.',
-            ['[{name}] in [{zone}]'.format(name=ref.clusterId,
-                                           zone=adapter.Zone(ref))
-             for ref in cluster_refs]),
+        message=util.ConstructList('The following clusters will be deleted.', [
+            '[{name}] in [{zone}]'.format(
+                name=ref.clusterId, zone=adapter.Zone(ref))
+            for ref in cluster_refs
+        ]),
         throw_if_unattended=True,
         cancel_on_no=True)
 
@@ -101,7 +104,8 @@ class Delete(base.DeleteCommand):
         operations.append((op_ref, cluster_ref))
       except apitools_exceptions.HttpError as error:
         errors.append(
-            str(exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)))
+            six.text_type(
+                exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)))
       except util.Error as error:
         errors.append(error)
     if not args.async:
@@ -121,8 +125,8 @@ class Delete(base.DeleteCommand):
             log.warning(error)
 
           if properties.VALUES.container.cluster.Get() == cluster_ref.clusterId:
-            properties.PersistProperty(
-                properties.VALUES.container.cluster, None)
+            properties.PersistProperty(properties.VALUES.container.cluster,
+                                       None)
           log.DeletedResource(cluster_ref)
         except apitools_exceptions.HttpError as error:
           errors.append(exceptions.HttpException(error, util.HTTP_ERROR_FORMAT))
@@ -130,5 +134,5 @@ class Delete(base.DeleteCommand):
           errors.append(error)
 
     if errors:
-      raise util.Error(util.ConstructList(
-          'Some requests did not succeed:', errors))
+      raise util.Error(
+          util.ConstructList('Some requests did not succeed:', errors))
